@@ -10,7 +10,7 @@
 #' More information on how \pkg{parsnip} is used for modeling is at
 #' \url{https://www.tidymodels.org/}.
 #'
-#' @inheritParams boost_tree
+#' @inheritParams nearest_neighbor
 #' @param select_features `TRUE` or `FALSE.` If `TRUE`, the model has the
 #'  ability to eliminate a predictor (via penalization). Increasing
 #'  `adjust_deg_free` will increase the likelihood of removing predictors.
@@ -92,5 +92,21 @@ translate.gen_additive_mod <- function(x, engine = x$engine, ...) {
 #' @export
 #' @keywords internal
 fit_xy.gen_additive_mod <- function(object, ...) {
-  rlang::abort("`fit()` must be used with GAM models (due to its use of formulas).")
+  trace <- rlang::trace_back()
+
+  if ("workflows" %in% trace$namespace) {
+    cli::cli_abort(
+      c("!" = "When working with generalized additive models, please supply the
+               model specification to {.fun workflows::add_model} along with a \\
+               {.arg formula} argument.",
+        "i" = "See {.help parsnip::model_formula} to learn more."),
+      call = NULL
+    )
+  }
+
+  cli::cli_abort(c(
+    "!" = "Please use {.fun fit} rather than {.fun fit_xy} to train \\
+           generalized additive models.",
+    "i" = "See {.help model_formula} to learn more."
+  ))
 }
