@@ -388,15 +388,6 @@ set_model_arg(
   has_submodel = FALSE
 )
 
-set_model_arg(
-  model = "mlp",
-  eng = "brulee",
-  parsnip = "mixture",
-  original = "mixture",
-  func = list(pkg = "dials", fun = "mixture"),
-  has_submodel = FALSE
-)
-
 set_model_arg(
   model = "mlp",
   eng = "brulee",
@@ -424,25 +415,6 @@ set_model_arg(
   has_submodel = FALSE
 )
 
-set_model_arg(
-  model = "mlp",
-  eng = "brulee",
-  parsnip = "momentum",
-  original = "momentum",
-  func = list(pkg = "dials", fun = "momentum"),
-  has_submodel = FALSE
-)
-
-
-set_model_arg(
-  model = "mlp",
-  eng = "brulee",
-  parsnip = "stop_iter",
-  original = "stop_iter",
-  func = list(pkg = "dials", fun = "stop_iter"),
-  has_submodel = FALSE
-)
-
 set_model_arg(
   model = "mlp",
   eng = "brulee",
